@@ -86,7 +86,13 @@ class QQuickPopupItem : public QQuickControl
 public:
     explicit QQuickPopupItem(QQuickPopup *popup);
 
+    void grabShortcut();
+    void ungrabShortcut();
+
 protected:
+    void updatePolish() override;
+
+    bool event(QEvent *event) override;
     bool childMouseEventFilter(QQuickItem *child, QEvent *event) override;
     void focusInEvent(QFocusEvent *event) override;
     void focusOutEvent(QFocusEvent *event) override;
@@ -105,11 +111,13 @@ protected:
     void localeChange(const QLocale &newLocale, const QLocale &oldLocale) override;
     void itemChange(ItemChange change, const ItemChangeData &data) override;
     void paddingChange(const QMarginsF &newPadding, const QMarginsF &oldPadding) override;
+    void spacingChange(qreal newSpacing, qreal oldSpacing) override;
 
     QFont defaultFont() const override;
 
 #ifndef QT_NO_ACCESSIBILITY
     QAccessible::Role accessibleRole() const override;
+    void accessibilityActiveChanged(bool active) override;
 #endif
 
 private:
@@ -128,7 +136,7 @@ public:
     void setParentItem(QQuickItem *parent);
 
 protected:
-    void itemGeometryChanged(QQuickItem *, const QRectF &, const QRectF &) override;
+    void itemGeometryChanged(QQuickItem *, QQuickGeometryChange, const QRectF &) override;
     void itemParentChanged(QQuickItem *, QQuickItem *parent) override;
     void itemChildRemoved(QQuickItem *, QQuickItem *child) override;
 
@@ -185,6 +193,7 @@ public:
     bool hasDim;
     bool visible;
     bool complete;
+    bool positioning;
     bool hasWidth;
     bool hasHeight;
     bool hasTopMargin;
